@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-#  -*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 """
 Action may be:
 - Dictionary
@@ -8,19 +8,22 @@ Action may be:
 - Ignore
 """
 from __future__ import print_function, unicode_literals
-from builtins import input
 
+import csv
 import os
-import time
 import re
 import sys
-import csv
+import time
+from builtins import input
 from subprocess import PIPE, Popen
+
+from babel.messages import pofile
 # import xlrd
 from openpyxl import load_workbook
-from babel.messages import pofile
+
 from os0 import os0
 from python_plus import _c
+
 try:
     from z0lib.z0lib import z0lib
 except ImportError:
@@ -31,16 +34,14 @@ except ImportError:
     import clodoo
 
 
-__version__ = "1.0.5"
+__version__ = "1.0.11"
 
 MAX_RECS = 100
 PUNCT = [' ', '.', ',', '!', ':']
 TNL_DICT = {}
 TNL_ACTION = {}
-SYNTAX = {
-    'string': re.compile(u'"([^"\\\n]|\\.|\\\n)*"'),
-}
-VERSIONS = ('14.0', '13.0', '12.0', '11.0', '10.0', '9.0', '8.0', '7.0', '6.1')
+SYNTAX = {'string': re.compile('"([^"\\\n]|\\.|\\\n)*"')}
+VERSIONS = ('15.0', '14.0', '13.0', '12.0', '11.0', '10.0', '9.0', '8.0', '7.0', '6.1')
 PROTECT_TOKENS = [
     'Adviser',
     'Apply',
@@ -56,7 +57,8 @@ PROTECT_TOKENS = [
     'Discard',
     'Display',
     'Dominica',
-    'done', 'Done',
+    'done',
+    'Done',
     'Export',
     'Kenya',
     'Journal',
@@ -64,7 +66,8 @@ PROTECT_TOKENS = [
     'Myanmar',
     'Name',
     'Niger',
-    'Partner', 'Partners',
+    'Partner',
+    'Partners',
     'Remove',
     'Report',
     'Run',
@@ -73,7 +76,10 @@ PROTECT_TOKENS = [
     'The rate of the currency to the currency of rate 1',
     'Uninstall',
     'Update',
-    'You can either upload a file from your computer or copy/paste an internet link to your file',
+    (
+        'You can either upload a file from your computer or '
+        'copy/paste an internet link to your file'
+    ),
 ]
 msg_time = time.time()
 
@@ -81,7 +87,7 @@ msg_time = time.time()
 def msg_burst(text):
     global msg_time
     t = time.time() - msg_time
-    if (t > 3):
+    if t > 3:
         print('\t', text)
         msg_time = time.time()
 
@@ -90,8 +96,9 @@ def set_odoo_path(ctx, version):
     if ctx['pofile']:
         return os.path.abspath(
             os.path.join(
-                os.path.dirname(
-                    ctx['pofile'].replace(ctx['branch'], version)), '..'))
+                os.path.dirname(ctx['pofile'].replace(ctx['branch'], version)), '..'
+            )
+        )
     odoo_path = os.path.expanduser('~/%s' % version)
     if not os.path.exists(odoo_path):
         print('\tPaths of Odoo %s not found' % version)
@@ -110,12 +117,14 @@ def change_name(ctx, filename, version):
 
 
 def term_wo_punct(msgid, msgstr):
-    if msgid and msgid[-1] in PUNCT:
-        if msgstr and msgstr[-1] == msgid[-1]:
-            msgstr = msgstr[0: -1]
-        msgid = msgid[0: -1]
-    elif msgstr and msgstr[-1] in PUNCT:
-        msgstr = msgstr[0: -1]
+    if msgid:
+        while msgid[-1] in PUNCT:
+            if msgstr and msgstr[-1] == msgid[-1]:
+                msgstr = msgstr[:-1]
+            msgid = msgid[:-1]
+    elif msgstr:
+        while msgstr[-1] in PUNCT:
+            msgstr = msgstr[:-1]
     if msgid and msgstr:
         caseid = 'U' if msgid[0].isupper() else 'l'
         casestr = 'U' if msgstr[0].isupper() else 'l'
@@ -135,8 +144,15 @@ def term_with_punct(msgid, msgstr, punct):
     return msgid + punct, msgstr + punct
 
 
-def load_default_dictionary(ctx, source):
+def term_with_tag(msgid, msgstr, ltag, rtag):
+    if not msgid.startswith(ltag):
+        msgid = ltag + msgid + rtag
+    if not msgstr.endswith(rtag):
+        msgstr = ltag + msgstr + rtag
+    return msgid, msgstr
 
+
+def load_default_dictionary(ctx, source):
     def process_row(ctx, module_rows, row):
         if isinstance(module_rows, list) and row['module']:
             if row['module'] == ctx['module_name']:
@@ -145,18 +161,20 @@ def load_default_dictionary(ctx, source):
         if not row['msgid'] or not row['msgstr']:
             return 0
         msgid, TNL_DICT[msgid] = term_wo_punct(
-            os0.u(row['msgid']), os0.u(row['msgstr']))
+            os0.u(row['msgid']), os0.u(row['msgstr'])
+        )
         if not TNL_DICT[msgid]:
             TNL_ACTION[msgid] = 'P'
             return 0
-        elif (msgid == TNL_DICT[msgid] or (
-                msgid[0] != ' ' and msgid[0] != '\n' and
-                msgid[0] == TNL_DICT[msgid][0].lower() and
-                msgid[1:] == TNL_DICT[msgid][1:])):
+        elif msgid == TNL_DICT[msgid] or (
+            msgid[0] != ' '
+            and msgid[0] != '\n'
+            and msgid[0] == TNL_DICT[msgid][0].lower()
+            and msgid[1:] == TNL_DICT[msgid][1:]
+        ):
             TNL_ACTION[msgid] = '*'
             return 0
-        if ctx['action'] and ctx['action'][0].upper() in (
-                'D', 'P', '*'):
+        if ctx['action'] and ctx['action'][0].upper() in ('D', 'P', '*'):
             TNL_ACTION[msgid] = ctx['action'][0].upper()
         else:
             TNL_ACTION[msgid] = 'D'
@@ -166,16 +184,14 @@ def load_default_dictionary(ctx, source):
         ctr = 0
         if ctx['opt_verbose']:
             print("\tReading %s into dictionary" % source)
-        csv.register_dialect('dict',
-                             delimiter=_c('\t'),
-                             quotechar=_c('"'),
-                             quoting=csv.QUOTE_MINIMAL)
+        csv.register_dialect(
+            'dict', delimiter=_c('\t'), quotechar=_c('"'), quoting=csv.QUOTE_MINIMAL
+        )
         csv_fd = open(source, 'rU')
         hdr_read = False
-        csv_obj = csv.DictReader(csv_fd,
-                                 fieldnames=[],
-                                 restkey='undef_name',
-                                 dialect='dict')
+        csv_obj = csv.DictReader(
+            csv_fd, fieldnames=[], restkey='undef_name', dialect='dict'
+        )
         module_rows = []
         for row in csv_obj:
             if not hdr_read:
@@ -193,28 +209,24 @@ def load_default_dictionary(ctx, source):
         ctr = 0
         if ctx['opt_verbose']:
             print("\tReading %s into dictionary" % source)
-        # wb = xlrd.open_workbook(source)
         wb = load_workbook(source)
         # sheet = wb.sheet_by_index(0)
-        for sheet in wb:
-            break
+        # for sheet in wb:
+        #     break
+        sheet = wb.active
         colnames = []
-        # for ncol in range(sheet.ncols):
         for ncol in sheet.columns:
-            # colnames.append(sheet.cell_value(0, ncol))
             colnames.append(ncol[0].value)
         module_rows = []
-        # for nrow in range(1, sheet.nrows):
         hdr = True
         for nrow in sheet.rows:
             if hdr:
                 hdr = False
                 continue
             row = {}
-            # for ncol in range(sheet.ncols):
             for ncol, cell in enumerate(nrow):
-                # row[colnames[ncol]] = sheet.cell_value(nrow, ncol)
-                row[colnames[ncol]] = cell.value
+                row[colnames[ncol]] = cell.value.replace(
+                    '\\n', '\n') if cell.value else cell.value
             ctr += process_row(ctx, module_rows, row)
         for row in module_rows:
             ctr += process_row(ctx, None, row)
@@ -233,16 +245,14 @@ def load_default_dictionary(ctx, source):
 
 
 def save_untranslated(ctx, untnl):
-    csv.register_dialect('transodoo',
-                         delimiter=_c(','),
-                         quotechar=_c('\"'),
-                         quoting=csv.QUOTE_MINIMAL)
+    csv.register_dialect(
+        'transodoo', delimiter=_c(','), quotechar=_c('\"'), quoting=csv.QUOTE_MINIMAL
+    )
     dict_name = os.path.expanduser('~/odoo_default_tnl.csv')
     with open(dict_name, 'wb') as fd:
         writer = csv.DictWriter(
-            fd,
-            fieldnames=('module', 'msgid', 'msgstr'),
-            dialect='transodoo')
+            fd, fieldnames=('module', 'msgid', 'msgstr'), dialect='transodoo'
+        )
         writer.writeheader()
         if untnl is None:
             sorted_list = sorted(TNL_DICT.keys(), key=lambda x: x.lower())
@@ -250,16 +260,14 @@ def save_untranslated(ctx, untnl):
             sorted_list = sorted(untnl, key=lambda x: x.lower())
         for item in sorted_list:
             msg_burst(item)
-            line = {
-                'module': '',
-                'msgid': os0.b(item),
-                'msgstr': '',
-            }
+            line = {'module': '', 'msgid': os0.b(item), 'msgstr': ''}
             if untnl is None:
                 line['msgstr'] = os0.b(TNL_DICT[item])
-            if untnl is not None or (not item.startswith(' ') and
-                                     not item.startswith('\n') and
-                                     not item.startswith('===')):
+            if untnl is not None or (
+                not item.startswith(' ')
+                and not item.startswith('\n')
+                and not item.startswith('===')
+            ):
                 writer.writerow(line)
     if ctx['opt_verbose']:
         print("*** Untranslated dictionary saved at %s ***" % dict_name)
@@ -308,10 +316,8 @@ def load_dictionary_from_file(ctx, pofn, def_action=None):
                     dummy = TNL_ACTION[msgid2]
                 elif '*' in TNL_ACTION:
                     dummy = TNL_ACTION['*']
-                while dummy not in ('D', 'P', 'E', 'I') and \
-                        len(dummy) <= 3:
-                    dummy = input(
-                        '>>> (Dictionary,Po,End,Ignore,<Text>)? ')
+                while dummy not in ('D', 'P', 'E', 'I') and len(dummy) <= 3:
+                    dummy = input('>>> (Dictionary,Po,End,Ignore,<Text>)? ')
                 if dummy == 'E':
                     TNL_ACTION['*'] = dummy
                     return
@@ -344,29 +350,44 @@ def parse_pofile(ctx, source, untnl):
             msgstr = os0.u(message.string)
             msgid2, msgstr2 = term_wo_punct(msgid, msgstr)
             punct = ''
-            if msgid and msgid[-1] in PUNCT:
-                punct = msgid[-1]
-                msgid, msgstr = term_with_punct(msgid, msgstr, punct)
+            ltag = ''
+            rtag = ''
+            x = re.match('<[^>]+>', msgid)
+            if x:
+                ltag = msgid2[:x.end()]
+                msgid2 = msgid2[x.end():]
+                x = re.search('<[^>]+>', msgid2)
+                if x:
+                    rtag = msgid2[x.start():x.end()]
+                    msgid2 = msgid2[:x.start()]
+                    msgid, msgstr = term_with_tag(msgid, msgstr, ltag, rtag)
+            if msgid:
+                punct = ""
+                while msgid[-1] in PUNCT:
+                    punct = '%s%s' % (msgid[-1], punct)
+                if punct:
+                    msgid, msgstr = term_with_punct(msgid, msgstr, punct)
             if not msgid:
-                for k, value in message.__dict__.iteritems():
+                for k, value in message.__dict__.items():
                     if k == 'string':
-                        message.string = ''
+                        message.string = u''
                     elif value:
                         setattr(message, k, value)
                 ctr += 1
             elif msgid2 in TNL_DICT and msgstr != TNL_DICT[msgid2]:
-                for k, value in message.__dict__.iteritems():
+                for k, value in message.__dict__.items():
                     if k == 'string':
-                        message.string = TNL_DICT[msgid2] + punct
+                        if ltag and rtag:
+                            message.string = ltag + TNL_DICT[msgid2] + rtag
+                        else:
+                            message.string = TNL_DICT[msgid2] + punct
                     elif value:
                         setattr(message, k, value)
                 ctr += 1
                 fdiff = True
             elif msgid and msgid2 not in TNL_DICT and msgid2 not in untnl:
                 if ctx['opt_verbose']:
-                    print('\tWarning: key <%s> not found in translation!'
-                          % msgid2)
-                # untnl.append(msgid2)
+                    print('\tWarning: key <%s> not found in translation!' % msgid2)
                 untnl[msgid2] = msgstr2
         if ctx['opt_verbose']:
             print("\t... %d records to update" % ctr)
@@ -379,20 +400,15 @@ def rewrite_pofile(ctx, pofn, target, version):
         print("\tWriting %s " % pofn)
     tmpfile = '%s.tmp' % pofn
     bakfile = '%s.bak' % pofn
-    pofile.write_po(open(tmpfile, 'w'), target)
-    cmd = ['makepo_it.py',
-           '-b%s' % version,
-           '-m%s' % ctx['module_name'],
-           tmpfile]
-    out, err = Popen(cmd,
-                     stdin=PIPE,
-                     stdout=PIPE,
-                     stderr=PIPE,
-                     shell=False).communicate()
-    fd = open(pofn, 'rB')
+    pofile.write_po(open(tmpfile, 'wb'), target)
+    cmd = ['makepo_it.py', '-b%s' % version, '-m%s' % ctx['module_name'], tmpfile]
+    out, err = Popen(
+        cmd, stdin=PIPE, stdout=PIPE, stderr=PIPE, shell=False
+    ).communicate()
+    fd = open(pofn, 'r')
     lefts = os0.u(fd.read()).split('\n')
     fd.close()
-    fd = open(tmpfile, 'rB')
+    fd = open(tmpfile, 'r')
     rights = os0.u(fd.read()).split('\n')
     jj = 0
     for ii in range(len(lefts)):
@@ -407,7 +423,7 @@ def rewrite_pofile(ctx, pofn, target, version):
                     rights.insert(jj, lefts[ii])
                     ii += 1
                 jj += 1
-    fd = open(tmpfile, 'w')
+    fd = open(tmpfile, 'wb')
     fd.write(os0.b('\n'.join(rights)))
     fd.close()
     if os.path.isfile(bakfile):
@@ -416,22 +432,27 @@ def rewrite_pofile(ctx, pofn, target, version):
         os.rename(pofn, bakfile)
     os.rename(tmpfile, pofn)
 
+
 def get_module_pofile_name(ctx, version):
     odoo_path = set_odoo_path(ctx, version)
     if odoo_path:
         module_path = False
         for root, dirs, files in os.walk(odoo_path):
-            if (root.find('__to_remove') < 0 and
-                    os.path.basename(root) == ctx['module_name'] and
-                    (os.path.isfile(os.path.join(
-                        root, '__manifest__.py')) or
-                     os.path.isfile(os.path.join(
-                         root, '__openerp__.py')))):
+            if (
+                root.find('__to_remove') < 0
+                and os.path.basename(root) == ctx['module_name']
+                and (
+                    os.path.isfile(os.path.join(root, '__manifest__.py'))
+                    or os.path.isfile(os.path.join(root, '__openerp__.py'))
+                )
+            ):
                 module_path = root
                 break
         if not module_path:
-            print('*** Module %s not found for Odoo %s !!!' % (
-                ctx['module_name'], version))
+            print(
+                '*** Module %s not found for Odoo %s !!!'
+                % (ctx['module_name'], version)
+            )
             return False
         print('Found path %s' % module_path)
         pofn = os.path.join(module_path, 'i18n', 'it.po')
@@ -443,17 +464,19 @@ def get_module_pofile_name(ctx, version):
 
 
 def load_dictionary(ctx):
-    if os.path.isdir(os.path.expanduser('~/devel')):
-        root = os.path.expanduser('~/devel')
-    elif os.path.isdir(os.path.expanduser('~/dev')):
-        root = os.path.expanduser('~/dev')
-    else:
-        print('Development directory ~/devel not found!')
-        return 1
+    root = os.environ.get('HOME_DEVEL')
+    if not root or not os.path.isdir(root):
+        if os.path.isdir(os.path.expanduser('~/odoo/devel')):
+            root = os.path.expanduser('~/odoo/devel')
+        elif os.path.isdir(os.path.expanduser('~/devel')):
+            root = os.path.expanduser('~/devel')
+        else:
+            print('Development directory ~/devel not found!')
+            return 1
     if ctx['dbg_template']:
         dict_name = os.path.join(root, 'pypi', 'tools', 'odoo_default_tnl')
     else:
-        dict_name = os.path.join(root, 'odoo_default_tnl')
+        dict_name = os.path.join(root, 'venv', 'bin', 'odoo_default_tnl')
     ctr = load_default_dictionary(ctx, dict_name)
     ctx['pofiles'] = {}
     ctx['ctrs'] = {'0': ctr}
@@ -480,7 +503,7 @@ def refresh_dictionary(ctx):
     dict_name = os.path.join(root, 'pypi', 'tools', 'odoo_default_tnl')
     load_default_dictionary(ctx, dict_name)
     load_dictionary_from_file(ctx, ctx['ref_pofile'], def_action=ctx['action'])
-    save_untranslated(ctx, None)
+    # save_untranslated(ctx, None)
 
 
 def set_header_pofile(ctx, pofile):
@@ -492,16 +515,19 @@ def set_header_pofile(ctx, pofile):
         elif line.startswith('"# *'):
             potext += r'"# %s\n"' % ctx['module_name'] + '\n'
         elif line.startswith('"Project-Id-Version:'):
-            potext += r'"Project-Id-Version: Odoo (%s)\n"' % ctx(
-                'branch', '') + '\n'
+            potext += r'"Project-Id-Version: Odoo (%s)\n"' % ctx('branch', '') + '\n'
         elif line.startswith('"Last-Translator:'):
-            potext += r'"Last-Translator: %s <%s>\n"' % (
-                'Antonio M. Vigliotti',
-                'antoniomaria.vigliotti@gmail.com') + '\n'
+            potext += (
+                r'"Last-Translator: %s <%s>\n"'
+                % ('Antonio M. Vigliotti', 'antoniomaria.vigliotti@gmail.com')
+                + '\n'
+            )
         elif line.startswith('"Language-Team:'):
-            potext += r'"Language-Team: %s (%s)\n"' % (
-                'Zeroincombenze',
-                'https://www.zeroincombenze.it/') + '\n'
+            potext += (
+                r'"Language-Team: %s (%s)\n"'
+                % ('Zeroincombenze', 'https://www.zeroincombenze.it/')
+                + '\n'
+            )
             potext += r'"Language: it_IT\n"' + '\n'
         elif line.startswith('"Language:'):
             pass
@@ -515,14 +541,13 @@ def set_header_pofile(ctx, pofile):
 
 
 def parse_file(ctx):
-    # untnl = []
     untnl = {}
     for version in ctx['pofiles'].keys():
         pofn = ctx['pofiles'][version]
         fdiff, target, untnl = parse_pofile(ctx, pofn, untnl)
         src = '/%s/' % version
         tgt = '/oca%s/' % version.split('.')[0]
-        oca_pofn = pofn.replace(src,tgt)
+        oca_pofn = pofn.replace(src, tgt)
         if not os.path.isfile(oca_pofn):
             oca_pofn = oca_pofn.replace('einvoice', 'fatturapa')
         if os.path.isfile(oca_pofn):
@@ -532,7 +557,7 @@ def parse_file(ctx):
                 print("No change done.")
         else:
             rewrite_pofile(ctx, pofn, target, version)
-    save_untranslated(ctx, untnl)
+    # save_untranslated(ctx, untnl)
     return 0
 
 
@@ -546,17 +571,13 @@ def connect_db(ctx):
         ctx['svc_protocol'] = ''
         db_found = False
         try:
-            uid, ctx = clodoo.oerp_set_env(ctx=ctx,
-                                           db=dbname,
-                                           oe_version=version)
+            uid, ctx = clodoo.oerp_set_env(ctx=ctx, db=dbname, oe_version=version)
             db_found = True
         except BaseException:
             dbname = '%s%s' % (ctx['db_prefix'], version.split('.')[0])
         if not db_found:
             try:
-                uid, ctx = clodoo.oerp_set_env(ctx=ctx,
-                                               db=dbname,
-                                               oe_version=version)
+                uid, ctx = clodoo.oerp_set_env(ctx=ctx, db=dbname, oe_version=version)
                 db_found = True
             except BaseException:
                 print("No DB %s found" % ctx['db_prefix'])
@@ -565,7 +586,6 @@ def connect_db(ctx):
 
 
 def upgrade_db(ctx):
-
     def write_tnl(ctx, model, ids, msgid, msgstr, ctr):
         if ids and len(ids) < MAX_RECS:
             for id in ids:
@@ -601,39 +621,47 @@ def upgrade_db(ctx):
         # Report translations are in ir.ui.view model
         #
         model = 'ir.translation'
-        # clodoo.unlinkL8(
-        #     ctx, model, clodoo.searchL8(
-        #         ctx, model, [('lang', '=', 'it_IT'),
-        #                      ('name', 'in', ('ir.module.module,description'
-        #                                      'ir.module.module,shortdesc',
-        #                                      'ir.module.module,summary'))]))
         for msgid2 in TNL_DICT:
             for punct in PUNCT + ['']:
                 msgid = msgid2 + punct
                 msgstr = TNL_DICT[msgid2] + punct
                 if ctx['opt_verbose']:
                     msg_burst(msgid)
-                ids = clodoo.searchL8(ctx, model,
-                                      [('lang', '=', 'it_IT'),
-                                       ('type', '=', 'model'),
-                                       ('src', '=', msgid),
-                                       ('module', '=', ctx['module_name']),
-                                       ('value', '!=', msgstr)])
+                ids = clodoo.searchL8(
+                    ctx,
+                    model,
+                    [
+                        ('lang', '=', 'it_IT'),
+                        ('type', '=', 'model'),
+                        ('src', '=', msgid),
+                        ('module', '=', ctx['module_name']),
+                        ('value', '!=', msgstr),
+                    ],
+                )
                 ctr = write_tnl(ctx, model, ids, msgid, msgstr, ctr)
                 ids = clodoo.searchL8(
-                    ctx, model,
-                    [('lang', '=', 'it_IT'),
-                     ('name', 'in', ('ir.actions.act_window,name',
-                                     'ir.model,name',
-                                     'ir.module.category,name',
-                                     'ir.module.module,description'
-                                     'ir.module.module,shortdesc',
-                                     'ir.module.module,summary',
-                                     'ir.ui.menu,name',
-                                     'ir.ui.view,arch_db',
-                                     )),
-                     ('src', '=', msgid),
-                     ('value', '!=', msgstr)])
+                    ctx,
+                    model,
+                    [
+                        ('lang', '=', 'it_IT'),
+                        (
+                            'name',
+                            'in',
+                            (
+                                'ir.actions.act_window,name',
+                                'ir.model,name',
+                                'ir.module.category,name',
+                                'ir.module.module,description'
+                                'ir.module.module,shortdesc',
+                                'ir.module.module,summary',
+                                'ir.ui.menu,name',
+                                'ir.ui.view,arch_db',
+                            ),
+                        ),
+                        ('src', '=', msgid),
+                        ('value', '!=', msgstr),
+                    ],
+                )
                 ctr = write_tnl(ctx, model, ids, msgid, msgstr, ctr)
         if ctx['opt_verbose']:
             print("\t... %d record upgraded" % ctr)
@@ -650,61 +678,58 @@ def delete_translation(ctx):
         print("\tDelete translation from DB %s" % dbname)
     model = 'ir.translation'
     clodoo.unlinkL8(
-        ctx, model, clodoo.searchL8(
-            ctx, model, [('lang', '=', 'it_IT'),
-                         ('module', '=', ctx['module_name'])]))
+        ctx,
+        model,
+        clodoo.searchL8(
+            ctx, model, [('lang', '=', 'it_IT'), ('module', '=', ctx['module_name'])]
+        ),
+    )
     return 0
 
 
 if __name__ == "__main__":
-    parser = z0lib.parseoptargs("Translate Odoo Package",
-                                "© 2018-2020 by SHS-AV s.r.l.",
-                                version=__version__)
-    parser.add_argument("-A", "--action",
-                        help="Action: Dict,Po,*",
-                        dest="action",
-                        metavar="name")
-    parser.add_argument('-B', '--debug-template',
-                        action='store_true',
-                        dest='dbg_template')
-    parser.add_argument("-b", "--branch",
-                        help="Odoo branch",
-                        dest="branch",
-                        metavar="version")
-    parser.add_argument("-c", "--config",
-                        help="configuration file",
-                        dest="conf_fn",
-                        metavar="file",
-                        default='./clodoo.conf')
-    parser.add_argument('-D', '--delete-translation',
-                        action='store_true',
-                        dest='del_tnl')
-    parser.add_argument("-d", "--dbname",
-                        help="DB name",
-                        dest="db_prefix",
-                        metavar="dbname",
-                        default='')
+    parser = z0lib.parseoptargs(
+        "Translate Odoo Package", "© 2018-2020 by SHS-AV s.r.l.", version=__version__
+    )
+    parser.add_argument(
+        "-A", "--action", help="Action: Dict,Po,*", dest="action", metavar="name"
+    )
+    parser.add_argument(
+        '-B', '--debug-template', action='store_true', dest='dbg_template'
+    )
+    parser.add_argument(
+        "-b", "--branch", help="Odoo branch", dest="branch", metavar="version"
+    )
+    parser.add_argument(
+        "-c",
+        "--config",
+        help="configuration file",
+        dest="conf_fn",
+        metavar="file",
+        default='./clodoo.conf',
+    )
+    parser.add_argument(
+        '-D', '--delete-translation', action='store_true', dest='del_tnl'
+    )
+    parser.add_argument(
+        "-d", "--dbname", help="DB name", dest="db_prefix", metavar="dbname", default=''
+    )
     parser.add_argument('-h')
-    parser.add_argument('-H', '--translate-html',
-                        action='store_true',
-                        dest='tnl_html')
-    parser.add_argument('-l', '--load-language',
-                        action='store_true',
-                        dest='load_language')
-    parser.add_argument('-m', '--module_name',
-                        action='store',
-                        help='filename',
-                        dest='module_name')
+    parser.add_argument('-H', '--translate-html', action='store_true', dest='tnl_html')
+    parser.add_argument(
+        '-l', '--load-language', action='store_true', dest='load_language'
+    )
+    parser.add_argument(
+        '-m', '--module_name', action='store', help='filename', dest='module_name'
+    )
     parser.add_argument('-n')
-    parser.add_argument('-p', '--pofile',
-                        action='store',
-                        help='pathname',
-                        dest='pofile')
+    parser.add_argument(
+        '-p', '--pofile', action='store', help='pathname', dest='pofile'
+    )
     parser.add_argument('-q')
-    parser.add_argument('-R', '--ref-pofile',
-                        action='store',
-                        help='pathname',
-                        dest='ref_pofile')
+    parser.add_argument(
+        '-R', '--ref-pofile', action='store', help='pathname', dest='ref_pofile'
+    )
     parser.add_argument('-V')
     parser.add_argument('-v')
     ctx = parser.parseoptargs(sys.argv[1:])
