@@ -24,25 +24,31 @@ optional arguments:
 from __future__ import print_function, unicode_literals
 import os
 import sys
-from io import BytesIO
+
+if sys.version_info[0] == 2:
+    from io import BytesIO
+else:
+    from io import StringIO
 import time
 import csv
 from os0 import os0
 from python_plus import _b, _c, _u
+
 try:
     from z0lib import z0lib
 except ImportError:
     import z0lib
 
 
-__version__ = "1.0.5"
+__version__ = "1.0.11"
 
 msg_time = time.time()
 
+
 def msg_burst(text):
     global msg_time
     t = time.time() - msg_time
-    if (t > 3):
+    if t > 3:
         print(text)
         msg_time = time.time()
 
@@ -80,19 +86,20 @@ def format_line(col_size, row, sep=None, flist=None):
 
 def convert_text(ctx, src_string):
     max_col_width = int(ctx['max_col_width'])
-    csv.register_dialect('odoo',
-                         delimiter=_c(','),
-                         quotechar=_c('\"'),
-                         quoting=csv.QUOTE_MINIMAL)
+    csv.register_dialect(
+        'odoo', delimiter=_c(','), quotechar=_c('\"'), quoting=csv.QUOTE_MINIMAL
+    )
     ctr = 0
     col_size = {}
     text = ''
-    csv_fd = BytesIO(_b(src_string))
+    if sys.version_info[0] == 2:
+        csv_fd = BytesIO(_b(src_string))
+    else:
+        csv_fd = StringIO(_u(src_string))
     hdr_read = False
-    csv_obj = csv.DictReader(csv_fd,
-                             fieldnames=[],
-                             restkey='undef_name',
-                             dialect='odoo')
+    csv_obj = csv.DictReader(
+        csv_fd, fieldnames=[], restkey='undef_name', dialect='odoo'
+    )
     for row in csv_obj:
         if not hdr_read:
             csv_obj.fieldnames = items_2_unicode(row['undef_name'])
@@ -106,12 +113,14 @@ def convert_text(ctx, src_string):
             for p in csv_obj.fieldnames:
                 col_size[p] = max(col_size[p], min(len(row[p]), max_col_width))
     csv_fd.close()
-    csv_fd = BytesIO(_b(src_string))
+    if sys.version_info[0] == 2:
+        csv_fd = BytesIO(_b(src_string))
+    else:
+        csv_fd = StringIO(_u(src_string))
     hdr_read = False
-    csv_obj = csv.DictReader(csv_fd,
-                             fieldnames=[],
-                             restkey='undef_name',
-                             dialect='odoo')
+    csv_obj = csv.DictReader(
+        csv_fd, fieldnames=[], restkey='undef_name', dialect='odoo'
+    )
     for row in csv_obj:
         if not hdr_read:
             row['undef_name'] = items_2_unicode(row['undef_name'])
@@ -128,8 +137,7 @@ def convert_text(ctx, src_string):
         else:
             ctr += 1
             text += format_line(col_size, row, flist=csv_obj.fieldnames)
-            text += format_line(col_size, row, sep=True,
-                                flist=csv_obj.fieldnames)
+            text += format_line(col_size, row, sep=True, flist=csv_obj.fieldnames)
     csv_fd.close()
     return text
 
@@ -142,7 +150,7 @@ def convert_file(ctx):
             src_string = _u(fd.read())
             target = convert_text(ctx, src_string)
         if not ctx['dst_file']:
-            ctx['dst_file'] = ctx['src_file'][0: -4] + '.rst'
+            ctx['dst_file'] = ctx['src_file'][0:-4] + '.rst'
         if ctx['dst_file'] == '/dev/tty':
             print(target)
         else:
@@ -155,23 +163,21 @@ def convert_file(ctx):
 def main(cli_args=None):
     # if not cli_args:
     #     cli_args = sys.argv[1:]
-    parser = z0lib.parseoptargs("Convert csv file into xml file",
-                                "© 2018-2021 by SHS-AV s.r.l.",
-                                version=__version__)
+    parser = z0lib.parseoptargs(
+        "Convert csv file into xml file",
+        "© 2018-2022 by SHS-AV s.r.l.",
+        version=__version__,
+    )
     parser.add_argument('-h')
-    parser.add_argument('-b', '--odoo-branch',
-                        action='store',
-                        dest='odoo_ver')
-    parser.add_argument('-m', '--max-col-width',
-                        action='store',
-                        dest='max_col_width',
-                        default="250")
+    parser.add_argument('-b', '--odoo-branch', action='store', dest='odoo_ver')
+    parser.add_argument(
+        '-m', '--max-col-width', action='store', dest='max_col_width', default="250"
+    )
     parser.add_argument('-n')
     parser.add_argument('-q')
     parser.add_argument('-V')
     parser.add_argument('-v')
     parser.add_argument('src_file')
-    parser.add_argument('dst_file',
-                        nargs='?')
+    parser.add_argument('dst_file', nargs='?')
     ctx = items_2_unicode(parser.parseoptargs(sys.argv[1:]))
-    return convert_file(ctx)
\ No newline at end of file
+    return convert_file(ctx)
